Coverage report

# Coverage report: 27%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 2526 | 1839 | 0 | 27%
setup.py | 17 | 17 | 0 | 0%
soxspipe/__init__.py | 6 | 0 | 0 | 100%
soxspipe/__version__.py | 1 | 0 | 0 | 100%
soxspipe/cl_utils.py | 97 | 84 | 0 | 13%
soxspipe/commonutils/__init__.py | 9 | 0 | 0 | 100%
soxspipe/commonutils/create_dispersion_map.py | 265 | 230 | 0 | 13%
soxspipe/commonutils/detect_continuum.py | 276 | 43 | 0 | 84%
soxspipe/commonutils/detector_lookup.py | 31 | 2 | 0 | 94%
soxspipe/commonutils/dispersion_map_to_pixel_arrays.py | 32 | 0 | 0 | 100%
soxspipe/commonutils/filenamer.py | 85 | 39 | 0 | 54%
soxspipe/commonutils/getpackagepath.py | 6 | 3 | 0 | 50%
soxspipe/commonutils/keyword_lookup.py | 42 | 3 | 0 | 93%
soxspipe/commonutils/polynomials.py | 46 | 0 | 0 | 100%
soxspipe/commonutils/set_of_files.py | 117 | 102 | 0 | 13%
soxspipe/commonutils/tests/__init__.py | 0 | 0 | 0 | 100%
soxspipe/commonutils/tests/test_create_dispersion_map.py | 55 | 55 | 0 | 0%
soxspipe/commonutils/tests/test_detect_continuum.py | 46 | 5 | 0 | 89%
soxspipe/commonutils/tests/test_detector_lookup.py | 58 | 58 | 0 | 0%
soxspipe/commonutils/tests/test_dispersion_map_to_pixel_arrays.py | 42 | 42 | 0 | 0%
soxspipe/commonutils/tests/test_filenamer.py | 56 | 56 | 0 | 0%
soxspipe/commonutils/tests/test_keyword_lookup.py | 52 | 52 | 0 | 0%
soxspipe/commonutils/tests/test_sof_of_files.py | 83 | 83 | 0 | 0%
soxspipe/docstring_test.py | 4 | 3 | 0 | 25%
soxspipe/recipes/__init__.py | 6 | 0 | 0 | 100%
soxspipe/recipes/_base_recipe_.py | 261 | 230 | 0 | 12%
soxspipe/recipes/soxs_disp_solution.py | 85 | 67 | 0 | 21%
soxspipe/recipes/soxs_mbias.py | 56 | 39 | 0 | 30%
soxspipe/recipes/soxs_mdark.py | 61 | 45 | 0 | 26%
soxspipe/recipes/soxs_order_centres.py | 96 | 78 | 0 | 19%
soxspipe/recipes/soxs_spatial_solution.py | 88 | 71 | 0 | 19%
soxspipe/recipes/tests/__init__.py | 0 | 0 | 0 | 100%
soxspipe/recipes/tests/test__base_recipe_.py | 49 | 49 | 0 | 0%
soxspipe/recipes/tests/test_soxs_disp_solution.py | 52 | 52 | 0 | 0%
soxspipe/recipes/tests/test_soxs_mbias.py | 108 | 108 | 0 | 0%
soxspipe/recipes/tests/test_soxs_mdark.py | 75 | 75 | 0 | 0%
soxspipe/recipes/tests/test_soxs_order_centres.py | 56 | 56 | 0 | 0%
soxspipe/recipes/tests/test_soxs_spatial_solution.py | 52 | 52 | 0 | 0%
soxspipe/tests/__init__.py | 0 | 0 | 0 | 100%
soxspipe/tests/test_cl_utils.py | 33 | 33 | 0 | 0%
soxspipe/utKit.py | 22 | 7 | 0 | 68%

No items found using the specified filter.